==> apache-camel-3.3.0-src.zip: apache-camel-3.3.0/core/camel-core/src/test/java/org/apache/camel/language/simple/SimpleResourceDynamicTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.language.simple;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.junit.Test;

/**
 *
 */
public class SimpleResourceDynamicTest extends ContextTestSupport {

    @Test
    public void testSimpleResource() throws Exception {
        getMockEndpoint("mock:result").expectedBodiesReceived("The name is Camel");

        template.sendBodyAndHeader("direct:start", "Camel", "myFileName", "mysimple.txt");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:start").transform().simple("resource:classpath:${header.myFileName}").to("mock:result");
            }
        };
    }
}

==> apache-camel-3.20.3-src.zip: apache-camel-3.20.3/core/camel-core/src/test/java/org/apache/camel/language/simple/SimpleResourceDynamicTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.language.simple;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

/**
 *
 */
public class SimpleResourceDynamicTest extends ContextTestSupport {

    @Test
    public void testSimpleResource() throws Exception {
        getMockEndpoint("mock:result").expectedBodiesReceived("The name is Camel");

        template.sendBodyAndHeader("direct:start", "Camel", "myFileName", "mysimple.txt");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from("direct:start").transform().simple("resource:classpath:${header.myFileName}").to("mock:result");
            }
        };
    }
}
